==> socratadata_0.1.0.tar.gz: socratadata/tests/testthat/soc_query/soda.demo.socrata.com/resource/4tka-6guv.json-c7c8ee.R <==
structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/4tka-6guv.json?%24select=magnitude%2C%20count%28%2A%29%20as%20count&%24where=magnitude%20%3E%206&%24group=magnitude&%24offset=10000&%24limit=10000", 
    status_code = 200L, headers = structure(list(Server = "nginx", 
        Date = "Tue, 22 Jul 2025 20:42:04 GMT", `Content-Type` = "application/json;charset=utf-8", 
        `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
        `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMzQxMl80XzEyMlA5RUpGSnJzcTRkM3NGdVkwUFlTUFUtUER5NA-oDLWpehJMUZvdqxD5UhWdp9VJXg--gzip--gzip\"", 
        `X-SODA2-Fields` = "[\"magnitude\",\"count\"]", `X-SODA2-Types` = "[\"number\",\"number\"]", 
        `X-SODA2-Data-Out-Of-Date` = "false", `X-SODA2-Truth-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `X-SODA2-Secondary-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", Vary = "Accept-Encoding", 
        `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
        `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
        `X-Socrata-RequestId` = "09823209890221af51e950baabc30ae2"), class = "httr2_headers"), 
    body = charToRaw("[]\n"), timing = c(redirect = 0, namelookup = 1.9e-05, 
    connect = 0, pretransfer = 6.3e-05, starttransfer = 0.196431, 
    total = 0.196549), cache = new.env(parent = emptyenv())), class = "httr2_response")

==> socratadata_0.1.1.tar.gz: socratadata/tests/testthat/soc_query/soda.demo.socrata.com/resource/4tka-6guv.json-c7c8ee.R <==
structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/4tka-6guv.json?%24select=magnitude%2C%20count%28%2A%29%20as%20count&%24where=magnitude%20%3E%206&%24group=magnitude&%24offset=10000&%24limit=10000", 
    status_code = 200L, headers = structure(list(Server = "nginx", 
        Date = "Mon, 18 Aug 2025 16:31:04 GMT", `Content-Type` = "application/json;charset=utf-8", 
        `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
        `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMzQxMl80XzEyMlA5RUpGSnJzcTRkM3NGdVkwUFlTUFUtUER5NA-oDLWpehJMUZvdqxD5UhWdp9VJXg--gzip--gzip\"", 
        `X-SODA2-Fields` = "[\"magnitude\",\"count\"]", `X-SODA2-Types` = "[\"number\",\"number\"]", 
        `X-SODA2-Data-Out-Of-Date` = "false", `X-SODA2-Truth-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `X-SODA2-Secondary-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", Vary = "Accept-Encoding", 
        `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
        `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
        `X-Socrata-RequestId` = "da34a831bd530a7a300b4bbbe9a9cb04"), class = "httr2_headers"), 
    body = charToRaw("[]\n"), timing = c(redirect = 0, namelookup = 1.6e-05, 
    connect = 0, pretransfer = 0.000103, starttransfer = 0.138577, 
    total = 0.138689), cache = new.env(parent = emptyenv())), class = "httr2_response")
